==> focess-qq-4.0.8.4000-sources.jar: top/focess/qq/core/bot/SimpleGroup.java <==
package top.focess.qq.core.bot;

import com.google.common.collect.Maps;
import org.jetbrains.annotations.Nullable;
import top.focess.qq.api.bot.Bot;
import top.focess.qq.api.bot.Group;
import top.focess.qq.api.bot.Member;

import java.util.Map;

public class SimpleGroup extends SimpleSpeaker implements Group {

    private static final Map<Long, Map<Long,SimpleGroup>> GROUP_MAP = Maps.newConcurrentMap();

    private final net.mamoe.mirai.contact.Group nativeGroup;

    private SimpleGroup(Bot bot, net.mamoe.mirai.contact.Group nativeGroup) {
        super(bot, nativeGroup);
        this.nativeGroup = nativeGroup;
    }

    @Nullable
    public static Group get(Bot bot, @Nullable net.mamoe.mirai.contact.Group group) {
        if (group == null)
            return null;
        if (bot.getId() != group.getBot().getId())
            return null;
        Map<Long,SimpleGroup> map = GROUP_MAP.computeIfAbsent(bot.getId(), k -> Maps.newConcurrentMap());
        return map.computeIfAbsent(group.getId(), k -> new SimpleGroup(bot, group));
    }

    public static void remove(Bot bot) {
        GROUP_MAP.remove(bot.getId());
    }

    @Override
    public String getName() {
        return this.nativeGroup.getName();
    }

    @Override
    public void quit() {
        this.nativeGroup.quit();
    }

    @Nullable
    @Override
    public Member getMember(long id) {
        return SimpleMember.get(this,this.nativeGroup.get(id));
    }

    @Override
    public Member getMemberOrFail(long id) {
        return SimpleMember.get(this,this.nativeGroup.getOrFail(id));
    }
}

==> focess-qq-4.0.8.5000-sources.jar: top/focess/qq/core/bot/SimpleGroup.java <==
package top.focess.qq.core.bot;

import com.google.common.collect.Maps;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.jetbrains.annotations.Nullable;
import top.focess.qq.api.bot.Bot;
import top.focess.qq.api.bot.Group;
import top.focess.qq.api.bot.Member;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

public class SimpleGroup extends SimpleTransmitter implements Group {

    private static final Map<Long, Map<Long,SimpleGroup>> GROUP_MAP = Maps.newConcurrentMap();

    private final net.mamoe.mirai.contact.Group nativeGroup;

    private SimpleGroup(Bot bot, net.mamoe.mirai.contact.Group nativeGroup) {
        super(bot, nativeGroup);
        this.nativeGroup = nativeGroup;
    }

    @Nullable
    public static Group get(Bot bot, @Nullable net.mamoe.mirai.contact.Group group) {
        if (group == null)
            return null;
        if (bot.getId() != group.getBot().getId())
            return null;
        Map<Long,SimpleGroup> map = GROUP_MAP.computeIfAbsent(bot.getId(), k -> Maps.newConcurrentMap());
        return map.computeIfAbsent(group.getId(), k -> new SimpleGroup(bot, group));
    }

    public static void remove(Bot bot) {
        GROUP_MAP.remove(bot.getId());
    }

    @Override
    public String getName() {
        return this.nativeGroup.getName();
    }

    @Override
    public void quit() {
        this.nativeGroup.quit();
    }

    @Nullable
    @Override
    public Member getMember(long id) {
        return SimpleMember.get(this,this.nativeGroup.get(id));
    }

    @Override
    public Member getMemberOrFail(long id) {
        return Objects.requireNonNull(SimpleMember.get(this,this.nativeGroup.getOrFail(id)));
    }

    @Override
    public @NonNull List<Member> getMembers() {
        return this.nativeGroup.getMembers().stream().map(i -> SimpleMember.get(this,i)).collect(Collectors.toList());
    }

}
